@@ -64,7 +64,9 @@ def setup_pybundle():
   with settings(warn_only=True):
     requirement = 'packages.txt'
     result = local("""
-      rm -f {requirement} && pip freeze --local > {requirement} && pip bundle --requirement={requirement} {application}.pybundle
+      if ! test -f {application}.pybundle; then
+        ( test -f {requirement} || pip freeze --local > {requirement} ) && pip bundle --requirement={requirement} {application}.pybundle;
+      fi
     """.format(**var('application', requirement=requirement)))
     if result.failed:
       error('failed to create pybundle.')
@@ -90,9 +92,9 @@ def update():
 def update_code():
   try:
     fetch('strategy').deploy()
-  except Exception, error:
+  except Exception, e:
     run('rm -rf {latest_release}; true'.format(**var('latest_release')))
-    error('failed to update code.')
+    error('failed to update code. ({reason})'.format(reason=str(e)))
 
   finalize_update()
 
